pub struct FiveTuple {
pub orig: SocketAddr,
pub resp: SocketAddr,
pub proto: usize,
}Expand description
Connection 5-tuple.
The sender of the first observed packet in the connection becomes the originator orig, and the
recipient becomes the responder resp.
Fields
orig: SocketAddrThe originator connection endpoint.
resp: SocketAddrThe responder connection endpoint.
proto: usizeThe layer-4 protocol.
Implementations
Sourceimpl FiveTuple
impl FiveTuple
Sourcepub fn dst_subnet_str(&self) -> String
pub fn dst_subnet_str(&self) -> String
Utility for returning a string representation of the dst. subnet /24 for IPv4, /64 for IPv6; no mask for broadcast
Sourcepub fn dst_ip_str(&self) -> String
pub fn dst_ip_str(&self) -> String
Utility for returning a string representation of the dst. IP
pub fn src_ip_str(&self) -> String
Sourcepub fn transp_proto_str(&self) -> String
pub fn transp_proto_str(&self) -> String
Utility for returning a string representation of the transport protocol and source/destination ports